Changes
~~~~~~~

Future (?)
----------
- More tests
- Talk to odoo upgrade service
- Metrics endpoint (to scrape progress/status)

0.5.1 (2018-11-04)
------------------
- Dummy release (pypi)

0.5.0 (2018-11-04)
------------------
- First dodoo release

0.0.1 (2018-10-23)
------------------
- First port of marabunta
